# The server exposes three types of endpoints:
# 1. RPC interface to collect metrics
# 2. Reporting interface to fetch metrics
# 3. Static content for the web interface

from mon.config import Metric
import mon.db

import flask
app = flask.Flask(__name__)

@app.route('/collect/<metric_name>', methods=['POST'])
def collect(metric_name):
    metric_config = Metric[metric_name]
    value = flask.request.form['value']
    timestamp = flask.request.form['timestamp']
    mon.db.record(metric_config, timestamp, value)
    return f'stored ({timestamp}, {value}) for {metric_config.name}.'

@app.route('/series/<metric_name>')
def series(metric_name):
    m = Metric[metric_name]
    response = flask.make_response(mon.db.format_tsv(m))
    response.headers['Content-Type'] = 'text/tab-separated-values'
    return response

@app.route('/')
def index():
    return flask.render_template('index.html', metrics=list(Metric))

@app.route('/view/<metric_name>')
def view(metric_name):
    m = Metric[metric_name]
    return flask.render_template('view.html', metric_name=m.name)

if __name__ == '__main__':
    import mon.db_main
    app.run(host='0.0.0.0')
