// vi: se ts=2 sw=2 et:
'use strict';

function render(data) {
  const margin = {top: 40, right: 40, bottom: 40, left: 40},
    width = 500 - margin.left - margin.right,
    height = 300 - margin.top - margin.bottom;

  const x_extent = d3.extent(data,
    d => d.timestamp);
  const y_extent = d3.extent(data,
    d => d.value);
  const x = d3.scaleTime()
    .domain(x_extent)
    .range([0, width]);
  const y = d3.scaleLinear()
    .domain(y_extent)
    .range([height, 0]);
  const line = d3.line()
    .defined(d => !Number.isNaN(d.value))
    .x(d => x(d.timestamp))
    .y(d => y(d.value));
  const area = d3.area()
    .defined(line.defined())
    .x(line.x())
    .y1(line.y())
    .y0(y(0));


  const svg = d3.select('body').append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr('transform', 'translate(' + margin.left + ',' + margin.top + ')')
    .datum(data);

  svg.append('path')
    .attr('class', 'line')
    .attr('d', line);

  svg.append('g')
    .attr('class', 'x axis')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(x));
  svg.append('g')
    .attr('class', 'y axis')
    .call(d3.axisLeft(y));
}

d3.tsv('/series/' + metric_name,
  d => {
    return {
      timestamp: +new Date(1000 * d.timestamp),
      value: parseFloat(d.value),
    }
  },
  (error, data) => {
    if (error) throw error;
    render(data);
  });
